View Source OTT (ott v0.1.0)
Documentation for OTT.
Summary
Functions
Access the token data.
Returns the data associated with the token only if the token has not been used and has not been revoked.
Otherwise, it returns nil.
Generates a one-time token for the specified data.
Options
:expires_in_minutes- the duration of validity for the token in minutes. Defaults to 5 minutes.:token_length- the length of the generated token. Defaults to 10 chars.